"""Module for fuzzy matching components."""
from .fuzzysearcher import FuzzySearcher


__all__ = ["FuzzySearcher"]
